@@ -1,8 +1,7 @@
-# BPNet-Lite
+# bpnet-lite
 # Author: Jacob Schreiber
 # Code adapted from Avanti Shrikumar and Ziga Avsec
 
 from .bpnet import BPNet
-from .io import DataGenerator
 
-__version__ == '0.0.1'
+__version__ == '0.0.2'
